@@ -28,7 +28,7 @@ void Player::openArticle(QString itemName, QString text, bool playlist)
 {
     qDebug()<<"player"<<playlist;
  //   if (playlist)
-   //     reload = true;
+ //     reload = true;
     QString stripped = itemName.toLower().remove(QRegExp("[^A-Za-z0-9]"));
     path = "/home/user/MyDocs/.audiowiki/" + stripped+".txt";
 
@@ -46,17 +46,17 @@ void Player::openArticle(QString itemName, QString text, bool playlist)
     connect(linkWidget, SIGNAL(linkClicked(QListWidgetItem*)), this, SLOT(linkListWidget_itemClicked(QListWidgetItem*)));
     qDebug()<<"reload"<<reload;
     bool audioExists = QFile("/home/user/MyDocs/.audiowiki/" +  stripped+".wav").exists();
+    if (itemName.contains("_"))
+        itemName.replace("_", " ");
+
+    QListWidgetItem *item = new QListWidgetItem(itemName);
     if (!reload)
     {
 
-        if (itemName.contains("_"))
-            itemName.replace("_", " ");
-
-        QListWidgetItem *item = new QListWidgetItem(itemName);
-
         ui->playListWidget->insertItem(ui->playListWidget->count(), item);
 
-        if (ui->playListWidget->count() > 1)
+
+        if (ui->playListWidget->count() > 1 && playlist == false)
             ui->playListWidget->setCurrentRow(ui->playListWidget->count()-1);
 
 
@@ -128,7 +128,7 @@ void Player::on_forwardButton_clicked()
 void Player::setPlaylistFocus()
 {
     reload = true;
-    this->ui->playListWidget->setCurrentRow(1, QItemSelectionModel::Select);
+    this->ui->playListWidget->setCurrentRow(0, QItemSelectionModel::Select);
 
     this->openArticleFromLink(ui->playListWidget->item(this->ui->playListWidget->currentRow()));
    // audio->createWav(this->ui->playListWidget->currentItem()->text());
